==> pytorch-ident-0.1.1.tar.gz: pytorch-ident-0.1.1/README.md <==
# System identification tools in PyTorch
A collection of system identification tools implemented in PyTorch.

* State-space identification methods (see [1], [2], [3])
* Differentiable transfer functions (see [4], [5])

## Examples and Documentation

See the [**examples**](examples) folder.


## Installation:

### Requirements:
A Python 3.9 conda environment with

 * numpy
 * scipy
 * matplotlib
 * pandas
 * pytorch
 
### Stable version from PyPI

Run the command 

```
pip install pytorch-ident
```
This will install the current [stable version](https://pypi.org/project/pytorch-ident/0.1/) from the PyPI package repository.

### Latest version from GitHub
1. Get a local copy the pyMPC project. For instance, run 
```
git clone https://github.com/forgi86/pytorch-ident.git
```
in a terminal to clone the project using git. Alternatively, download the zipped project from [this link](https://github.com/forgi86/pytorch-ident/zipball/master) and extract it in a local folder

2. Install pytorch-ident by running
```
pip install -e .
```
in the project root folder (where the file setup.py is located). 

# Bibliography
[1] M. Forgione and D. Piga. Model structures and fitting criteria for system identification with neural networks. In Proceedings of the 14th IEEE International Conference Application of Information and Communication Technologies, 2020. <br/><br/>
[2] B. Mavkov, M. Forgione, D. Piga. Integrated Neural Networks for Nonlinear Continuous-Time System Identification. IEEE Control Systems Letters, 4(4), pp 851-856, 2020. <br/><br/>
[3] M. Forgione and D. Piga. Continuous-time system identification with neural networks: model structures and fitting criteria. European Journal of Control, 59:68-81, 2021. <br/><br/>
[4] M. Forgione and D. Piga. dynoNet: a neural network architecture for learning dynamical systems. International Journal of Adaptive Control and Signal Processing, 2021. <br/><br/>
[5] D. Piga, M.Forgione and M. Mejari. Deep learning with transfer functions: new applications in system identification. In Proceedings of the the 2021 SysId Conference, 2021. <br/><br/>

==> pytorch-ident-0.2.1.tar.gz: pytorch-ident-0.2.1/README.md <==
# System identification tools in PyTorch
A collection of system identification tools implemented in PyTorch.

* State-space identification methods (see [1], [2], [3])
* Differentiable transfer functions (see [4], [5])

## Examples and Documentation

See the [**examples**](examples) folder.


## Installation:

### Requirements:
A Python 3.9 conda environment with

 * numpy
 * scipy
 * matplotlib
 * pandas
 * pytorch
 
### Stable version from PyPI

Run the command 

```
pip install pytorch-ident
```
This will install the current [stable version](https://pypi.org/project/pytorch-ident/) from the PyPI package repository.

### Latest version from GitHub
1. Get a local copy the pyMPC project. For instance, run 
```
git clone https://github.com/forgi86/pytorch-ident.git
```
in a terminal to clone the project using git. Alternatively, download the zipped project from [this link](https://github.com/forgi86/pytorch-ident/zipball/master) and extract it in a local folder

2. Install pytorch-ident by running
```
pip install -e .
```
in the project root folder (where the file setup.py is located). 

# Bibliography
[1] M. Forgione and D. Piga. Model structures and fitting criteria for system identification with neural networks. In Proceedings of the 14th IEEE International Conference Application of Information and Communication Technologies, 2020. <br/><br/>
[2] B. Mavkov, M. Forgione, D. Piga. Integrated Neural Networks for Nonlinear Continuous-Time System Identification. IEEE Control Systems Letters, 4(4), pp 851-856, 2020. <br/><br/>
[3] M. Forgione and D. Piga. Continuous-time system identification with neural networks: model structures and fitting criteria. European Journal of Control, 59:68-81, 2021. <br/><br/>
[4] M. Forgione and D. Piga. dynoNet: a neural network architecture for learning dynamical systems. International Journal of Adaptive Control and Signal Processing, 2021. <br/><br/>
[5] D. Piga, M.Forgione and M. Mejari. Deep learning with transfer functions: new applications in system identification. In Proceedings of the the 2021 SysId Conference, 2021. <br/><br/>
